# How to cite jQMC

(citation_of_jQMC)=

## Citation of jQMC

If you used jQMC in your reseach project, please cite the following articles.
This indeed helps the jQMC project to continue:

- "Load-Balanced Diffusion Monte Carlo Method with Lattice Regularization",

  [K. Nakano, S. Sorella, and M. Casula, J. Chem. Phys. 163, 194117 (2025)](https://doi.org/10.1063/5.0296986)

  ```
  @article{10.1063/5.0296986,
      author = {Nakano, Kousuke and Sorella, Sandro and Casula, Michele},
      title = {Load-balanced diffusion Monte Carlo method with lattice regularization},
      journal = {J. Chem. Phys.},
      volume = {163},
      number = {19},
      pages = {194117},
      year = {2025},
      month = {11},
      doi = {10.1063/5.0296986}
  }

- "jQMC: JAX-based ab initio Quantum Monte Carlo package",

  Kosuke Nakano, and Michele Casula, in preparation (2026)

  ```
  @article{nakano-jqmc,
    author  = {Nakano, Kosuke and Casula, Michele},
    title   = {jQMC: JAX-based ab initio Quantum Monte Carlo package},
    journal = {in preparation},
    %volume  = {},
    %number  = {},
    %pages   = {},
    year    = {2026},
    %doi     = {}
  }
  ```
